#
# Configure paths and flags for the AirInv library.
# Denis Arnaud <denis_arnaud at users dot sourceforge dot net>, July 2008
#
# Note: the AIRINV library depends upon BOOST to build.
# Your configure.ac must therefore define appropriately the BOOST
# variables (i.e., BOOST_CFLAGS, BOOST_LIBS, BOOST_DATE_TIME_LIB).
#
# Variables set by this macro:
#  * AIRINV_VERSION
#  * AIRINV_CFLAGS
#  * AIRINV_LIBS
#  * AIRINV_SAMPLE_DIR
#

AC_DEFUN([AM_PATH_AIRINV],
[
AC_LANG_SAVE
AC_LANG([C++])

##
AC_ARG_WITH(airinv,
	[ --with-airinv=PFX Prefix where AirInv is installed (optional) ],
	    airinv_dir="$withval",
	    airinv_dir="")

  if test "x${AIRINV_CONFIG+set}" != xset ; then
     if test "x$airinv_dir" != x ; then
         AIRINV_CONFIG="$airinv_dir/bin/airinv-config"
     fi
  fi

  AC_PATH_PROG(AIRINV_CONFIG, airinv-config, no)

  ## Check whether Boost flags and libraries are defined
  # General Boost compilation flags
  AC_MSG_CHECKING(for BOOST_CFLAGS environment variable)
  if test x"${BOOST_CFLAGS}" = x; then
	AC_MSG_RESULT([Warning: AirInv needs Boost, and the BOOST_CFLAGS environment variable does not appear to be set. It may not be a problem, though, if your Unix distribution is standard, that is, if Boost is installed in /usr. Otherwise, the AirInv will fail to compile.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_CFLAGS})])
  fi

  # Boost Date-Time library
  AC_MSG_CHECKING(for BOOST_DATE_TIME_LIB environment variable)
  if test x"${BOOST_DATE_TIME_LIB}" = x; then
	AC_MSG_RESULT([Warning: AirInv needs the Boost Date-Time library, and the BOOST_DATE_TIME_LIB environment variable does not appears to be set. The AirInv may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_DATE_TIME_LIB})])
  fi

  # Boost Program Options library
  AC_MSG_CHECKING(for BOOST_PROGRAM_OPTIONS_LIB environment variable)
  if test x"${BOOST_PROGRAM_OPTIONS_LIB}" = x; then
	AC_MSG_RESULT([Warning: AirInv needs the Boost Program Options library, and the BOOST_PROGRAM_OPTIONS_LIB environment variable does not appears to be set. The AirInv may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_PROGRAM_OPTIONS_LIB})])
  fi

  # Boost File System library
  AC_MSG_CHECKING(for BOOST_FILESYSTEM_LIB environment variable)
  if test x"${BOOST_FILESYSTEM_LIB}" = x; then
	AC_MSG_RESULT([Warning: AirInv needs the Boost Date-Time library, and the BOOST_FILESYSTEM_LIB environment variable does not appears to be set. The AirInv may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_FILESYSTEM_LIB})])
  fi

  ## AirInv version
  min_airinv_version=ifelse([$1], ,0.1.0,$1)
  AC_MSG_CHECKING(for AirInv - version >= $min_airinv_version)
  no_airinv=""
  if test "${AIRINV_CONFIG}" = "no" ; then
     no_airinv=yes
     AC_MSG_RESULT([no])
  else
     AIRINV_VERSION=`${AIRINV_CONFIG} --version`
     AIRINV_CFLAGS=`${AIRINV_CONFIG} --cflags`
     AIRINV_CFLAGS="${BOOST_CFLAGS} ${AIRINV_CFLAGS}"
     AIRINV_LIBS=`${AIRINV_CONFIG} --libs`
     AIRINV_LIBS="${BOOST_LIBS} ${BOOST_DATE_TIME_LIB} ${AIRINV_LIBS}"
     AIRINV_SAMPLE_DIR=`${AIRINV_CONFIG} --sampledir`

     AC_SUBST([AIRINV_VERSION])
     AC_SUBST([AIRINV_CFLAGS])
     AC_SUBST([AIRINV_LIBS])
     AC_SUBST([AIRINV_SAMPLE_DIR])

    airinv_major_version=`echo ${AIRINV_VERSION} | sed 's/^\([[0-9]]*\).*/\1/'`
    if test "x${airinv_major_version}" = "x" ; then
       airinv_major_version=0
    fi

    airinv_minor_version=`echo ${AIRINV_VERSION} | \
						sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\2/'`
    if test "x${airinv_minor_version}" = "x" ; then
       airinv_minor_version=0
    fi

    airinv_micro_version=`echo ${AIRINV_VERSION} | \
          sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\3/'`
    if test "x${airinv_micro_version}" = "x" ; then
       airinv_micro_version=0
    fi

    ## Simple test of compilation and link
    SAVED_CPPFLAGS="${CPPFLAGS}"
    SAVED_LDFLAGS="${LDFLAGS}"
    CPPFLAGS="${CPPFLAGS} ${BOOST_CFLAGS} ${AIRINV_CFLAGS}"
    LDFLAGS="${LDFLAGS} ${AIRINV_LIBS}"


    AC_COMPILE_IFELSE(
		[AC_LANG_PROGRAM([[#include <airinv/AIRINV_Service.hpp>
				]],
				[[int i=0;]]
		)]
		,

    	[AC_MSG_RESULT([yes (${AIRINV_VERSION})])],

	[AC_MSG_ERROR([We could not compile a simple AirInv example. See config.log.])]
    )

    CPPFLAGS="${SAVED_CPPFLAGS}"
    LDFLAGS="${SAVED_LDFLAGS}"

  fi

AC_LANG_RESTORE
])
